@@ -133,6 +133,7 @@ class JupyterApp(Application):
 
     def write_default_config(self) -> None:
         """Write our default config to a .py config file"""
+        config_file: str
         if self.config_file:
             config_file = self.config_file
         else:
@@ -142,7 +143,7 @@ class JupyterApp(Application):
             answer = ""
 
             def ask() -> str:
-                prompt = "Overwrite %s with default config? [y/N]" % config_file
+                prompt = f"Overwrite {config_file!r} with default config? [y/N]"
                 try:
                     return input(prompt).lower() or "n"
                 except KeyboardInterrupt:
@@ -157,7 +158,7 @@ class JupyterApp(Application):
                 return
 
         config_text = self.generate_config_file()
-        print("Writing default config to: %s" % config_file)
+        print(f"Writing default config to: {config_file!r}")
         ensure_dir_exists(Path(config_file).parent.resolve(), 0o700)
         with Path.open(Path(config_file), mode="w", encoding="utf-8") as f:
             f.write(config_text)
@@ -176,7 +177,7 @@ class JupyterApp(Application):
             f_marker.close()
             return  # so we must have already migrated -> bail out
 
-        from .migrate import get_ipython_dir, migrate
+        from .migrate import get_ipython_dir, migrate  # noqa: PLC0415
 
         # No IPython dir, nothing to migrate
         if not Path(get_ipython_dir()).exists():
@@ -263,7 +264,7 @@ class JupyterApp(Application):
     def start(self) -> None:
         """Start the whole thing"""
         if self.subcommand:
-            os.execv(self.subcommand, [self.subcommand] + self.argv[1:])  # noqa: S606
+            os.execv(self.subcommand, [self.subcommand, *self.argv[1:]])  # noqa: S606
             raise NoStart()
 
         if self.subapp:
@@ -286,9 +287,12 @@ class JupyterApp(Application):
         loop.close()
 
 
-class JupyterAsyncApp(Application):
+class JupyterAsyncApp(JupyterApp):
     """A Jupyter application that runs on an asyncio loop."""
 
+    name = "jupyter_async"  # override in subclasses
+    description = "An Async Jupyter Application"
+
     # Set to True for tornado-based apps.
     _prefer_selector_loop = False
 
