@@ -301,7 +301,7 @@ def test_jupyter_path_user_site():
                 ]
             )
         )
-        for p, v in zip(path, values):
+        for p, v in zip(path, values, strict=False):
             assert p == v
 
 
@@ -358,7 +358,7 @@ def test_jupyter_config_path():
             ]
         )
     )
-    for p, v in zip(path, values):
+    for p, v in zip(path, values, strict=False):
         assert p == v
 
 
@@ -383,7 +383,7 @@ def test_jupyter_config_path_prefer_env():
             ]
         )
     )
-    for p, v in zip(path, values):
+    for p, v in zip(path, values, strict=False):
         assert p == v
 
 
@@ -473,6 +473,19 @@ def test_is_hidden():
             assert is_hidden(subdir78, root)
 
 
+@pytest.mark.parametrize(
+    ("abs_path", "abs_root"),
+    [
+        ("relative.py", "/absolute"),
+        ("/absolute/path.py", "relative"),
+        ("/absolute/path.py", "/absolute/not/parent"),
+    ],
+)
+def test_is_hidden_invalid(abs_path, abs_root):
+    with pytest.raises(ValueError, match="abs"):
+        is_hidden(abs_path, abs_root)
+
+
 @pytest.mark.skipif(
     not (
         sys.platform == "win32"
@@ -499,7 +512,7 @@ def test_is_hidden_win32_cpython():
     reason="only run on windows/pypy < 7.3.6: https://foss.heptapod.net/pypy/pypy/-/issues/3469",
 )
 def test_is_hidden_win32_pypy():
-    import ctypes  # noqa: F401
+    import ctypes  # noqa: F401, PLC0415
 
     with tempfile.TemporaryDirectory() as root:
         subdir1 = os.path.join(root, "subdir")
